%--------------------------------------------------------------------------
% File     : BOO026-1 : TPTP v2.2.1. Released v2.2.0.
% Domain   : Boolean Algebra
% Problem  : Absorption from self-dual independent 2-basis
% Version  : [MP96] (eqiality) axioms : Especial.
% English  : This is part of a proof that there exists an independent self-dual
%            2-basis for Boolean Algebra.  You may note that the basis
%            below has more than 2 equations; but don't worry, it can be
%            reduced to 2 (large) equations by Pixley reduction.

% Refs     : [Wos98] Wos (1998), Automating the Search for Elegant Proofs
%          : [McC98] McCune (1998), Email to G. Sutcliffe
%          : [MP96]  McCune & Padmanabhan (1996), Automated Deduction in Eq
% Source   : [McC98]
% Names    : DUAL-BA-3 [MP96]
%          : DUAL-BA-3 [Wos98]

% Status   : unsatisfiable
% Rating   : ? v2.2.0
% Syntax   : Number of clauses    :   19 (   0 non-Horn;  12 unit;   4 RR)
%            Number of literals   :   27 (  27 equality)
%            Maximal clause size  :    3 (   1 average)
%            Number of predicates :    1 (   0 propositional; 2-2 arity)
%            Number of functors   :    7 (   4 constant; 0-2 arity)
%            Number of variables  :   40 (   0 singleton)
%            Maximal term depth   :    5 (   1 average)

% Comments : The original proof has 816 steps.  Wos later found a 99-step
%            proof.
%--------------------------------------------------------------------------
%----Include axioms of equality
include('Axioms/EQU001-0.ax').
%--------------------------------------------------------------------------
input_clause(add_substitution_1,axiom,
    [--equal(A,B),
     ++equal(add(A,C),add(B,C))]).

input_clause(add_substitution_2,axiom,
    [--equal(A,B),
     ++equal(add(C,A),add(C,B))]).

input_clause(inverse_substitution_1,axiom,
    [--equal(A,B),
     ++equal(inverse(A),inverse(B))]).

input_clause(multiply_substitution_1,axiom,
    [--equal(A,B),
     ++equal(multiply(A,C),multiply(B,C))]).

input_clause(multiply_substitution_2,axiom,
    [--equal(A,B),
     ++equal(multiply(C,A),multiply(C,B))]).

%----Two Boolean algebra properties and their duals:
input_clause(multiply_add_property,axiom,
    [++equal(multiply(X,add(Y,Z)),add(multiply(Y,X),multiply(Z,X)))]).

input_clause(additive_inverse,axiom,
    [++equal(add(X,inverse(X)),1)]).

input_clause(add_multiply_property,axiom,
    [++equal(add(X,multiply(Y,Z)),multiply(add(Y,X),add(Z,X)))]).

input_clause(multiplicative_inverse,axiom,
    [++equal(multiply(X,inverse(X)),0)]).

%----Expanded Pixley properties and their duals:
input_clause(pixley1,axiom,
    [++equal(add(multiply(X,inverse(X)),add(multiply(X,Y),
multiply(inverse(X),Y))),Y)]).

input_clause(pixley2,axiom,
    [++equal(add(multiply(X,inverse(Y)),add(multiply(X,Y),
multiply(inverse(Y),Y))),X)]).

input_clause(pixley3,axiom,
    [++equal(add(multiply(X,inverse(Y)),add(multiply(X,X),
multiply(inverse(Y),X))),X)]).

input_clause(pixley1_dual,axiom,
    [++equal(multiply(add(X,inverse(X)),multiply(add(X,Y),
add(inverse(X),Y))),Y)]).

input_clause(pixley2_dual,axiom,
    [++equal(multiply(add(X,inverse(Y)),multiply(add(X,Y),
add(inverse(Y),Y))),X)]).

input_clause(pixley3_dual,axiom,
    [++equal(multiply(add(X,inverse(Y)),multiply(add(X,X),
add(inverse(Y),X))),X)]).

%----Denial of the conclusion:
input_clause(prove_multiply_add,conjecture,
    [--equal(multiply(add(a,b),b),b)]).
%--------------------------------------------------------------------------
