%--------------------------------------------------------------------------
% File     : GRP025-3 : TPTP v2.2.1. Bugfixed v1.2.1.
% Domain   : Group Theory (Named groups)
% Problem  : All groups of order 2 are isomorphic
% Version  : [MOW76] axioms : Incomplete.
%            Theorem formulation : Does not prove full generality.
% English  : If G1 has exactly two elements and G2 has exactly two 
%            elements, then there exists an isomorphism [a one-to-one and 
%            onto homomorphism] between them.

% Refs     : [MOW76] McCharen et al. (1976), Problems and Experiments for a
% Source   : [ANL]
% Names    : order2.ver3.in [ANL]

% Status   : unsatisfiable
% Rating   : 1.00 v2.0.0
% Syntax   : Number of clauses    :   47 (   2 non-Horn;  25 unit;  36 RR)
%            Number of literals   :   85 (   0 equality)
%            Maximal clause size  :    4 (   1 average)
%            Number of predicates :    3 (   0 propositional; 2-4 arity)
%            Number of functors   :   13 (   9 constant; 0-3 arity)
%            Number of variables  :   90 (   0 singleton)
%            Maximal term depth   :    2 (   1 average)

% Comments : In order to prove the theorem, the group tables and a
%            particular homomorphism are specified, and the contradiction
%            comes from the fact that this is the actual isomorphism. Not
%            only is this formulation cheating, but also it does not prove
%            the theorem in full generality.
%          : Missing an_isomorphism subsitution axioms.
% Bugfixes : v1.2.1 - Bugfix in GRP006-0.ax.
%--------------------------------------------------------------------------
%----Don't include equality axioms because it's incomplete
%include('Axioms/EQU001-0.ax').
%----Include the axioms for named groups 
%include('Axioms/GRP006-0.ax').
%----Include the equality axioms for named groups 
%include('Axioms/GRP006-0.eq').
%--------------------------------------------------------------------------
input_clause(reflexivity,axiom,
    [++equalish(X,X)]).

input_clause(symmetry,axiom,
    [--equalish(X,Y),
     ++equalish(Y,X)]).

input_clause(transitivity,axiom,
    [--equalish(X,Y),
     --equalish(Y,Z),
     ++equalish(X,Z)]).

input_clause(identity_in_group,axiom,
    [++group_member(identity_for(Xg),Xg)]).

input_clause(left_identity,axiom,
    [++product(Xg,identity_for(Xg),X,X)]).

input_clause(right_identity,axiom,
    [++product(Xg,X,identity_for(Xg),X)]).

input_clause(inverse_in_group,axiom,
    [--group_member(X,Xg),
     ++group_member(inverse(Xg,X),Xg)]).

input_clause(left_inverse,axiom,
    [++product(Xg,inverse(Xg,X),X,identity_for(Xg))]).

input_clause(right_inverse,axiom,
    [++product(Xg,X,inverse(Xg,X),identity_for(Xg))]).

%----These axioms are called closure or totality in some axiomatisations 
input_clause(total_function1_1,axiom,
    [--group_member(X,Xg),
     --group_member(Y,Xg),
     ++product(Xg,X,Y,multiply(Xg,X,Y))]).

input_clause(total_function1_2,axiom,
    [--group_member(X,Xg),
     --group_member(Y,Xg),
     ++group_member(multiply(Xg,X,Y),Xg)]).

%----This axiom is called well_definedness in some axiomatisations 
input_clause(total_function2,axiom,
    [--product(Xg,X,Y,Z),
     --product(Xg,X,Y,W),
     ++equalish(W,Z)]).

input_clause(associativity1,axiom,
    [--product(Xg,X,Y,Xy),
     --product(Xg,Y,Z,Yz),
     --product(Xg,Xy,Z,Xyz),
     ++product(Xg,X,Yz,Xyz)]).

input_clause(associativity2,axiom,
    [--product(Xg,X,Y,Xy),
     --product(Xg,Y,Z,Yz),
     --product(Xg,X,Yz,Xyz),
     ++product(Xg,Xy,Z,Xyz)]).

input_clause(product_substitution1,axiom,
    [--equalish(Xg,Yg),
     --product(Xg,X,Y,Z),
     ++product(Yg,X,Y,Z)]).

input_clause(product_substitution2,axiom,
    [--equalish(X,Y),
     --product(Xg,X,Z,W),
     ++product(Xg,Y,Z,W)]).

input_clause(product_substitution3,axiom,
    [--equalish(X,Y),
     --product(Xg,W,X,Z),
     ++product(Xg,W,Y,Z)]).

input_clause(product_substitution4,axiom,
    [--equalish(X,Y),
     --product(Xg,W,Z,X),
     ++product(Xg,W,Z,Y)]).

input_clause(multiply_substitution1,axiom,
    [--equalish(Xg,Yg),
     ++equalish(multiply(Xg,X,Y),multiply(Yg,X,Y))]).

input_clause(multiply_substitution2,axiom,
    [--equalish(X,Y),
     ++equalish(multiply(Xg,X,Z),multiply(Xg,Y,Z))]).

input_clause(multiply_substitution3,axiom,
    [--equalish(X,Y),
     ++equalish(multiply(Xg,Z,X),multiply(Xg,Z,Y))]).

input_clause(inverse_substitution1,axiom,
    [--equalish(Xg,Yg),
     ++equalish(inverse(Xg,X),inverse(Yg,X))]).

input_clause(inverse_substitution2,axiom,
    [--equalish(X,Y),
     ++equalish(inverse(Xg,X),inverse(Xg,Y))]).

input_clause(group_member_substitution1,axiom,
    [--equalish(Xg,Yg),
     --group_member(X,Xg),
     ++group_member(X,Yg)]).

input_clause(group_member_substitution2,axiom,
    [--equalish(X,Y),
     --group_member(X,Xg),
     ++group_member(Y,Xg)]).

input_clause(identity_substitution,axiom,
    [--equalish(Xg,Yg),
     ++equalish(identity_for(Xg),identity_for(Yg))]).

%----Definition of the two groups 
input_clause(a_member_of_group1,hypothesis,
    [++group_member(a,g1)]).

input_clause(b_member_of_group1,hypothesis,
    [++group_member(b,g1)]).

input_clause(c_member_of_group2,hypothesis,
    [++group_member(c,g2)]).

input_clause(d_member_of_group2,hypothesis,
    [++group_member(d,g2)]).

input_clause(a_and_b_only_members_of_group1,hypothesis,
    [--group_member(X,g1),
     ++equalish(X,a),
     ++equalish(X,b)]).

input_clause(c_and_d_only_members_of_group2,hypothesis,
    [--group_member(X,g2),
     ++equalish(X,c),
     ++equalish(X,d)]).

input_clause(a_times_a_is_a,hypothesis,
    [++product(g1,a,a,a)]).

input_clause(a_times_b_is_b,hypothesis,
    [++product(g1,a,b,b)]).

input_clause(b_times_a_is_b,hypothesis,
    [++product(g1,b,a,b)]).

input_clause(b_times_b_is_a,hypothesis,
    [++product(g1,b,b,a)]).

input_clause(c_times_c_is_c,hypothesis,
    [++product(g2,c,c,c)]).

input_clause(c_times_d_is_d,hypothesis,
    [++product(g2,c,d,d)]).

input_clause(d_times_c_is_d,hypothesis,
    [++product(g2,d,c,d)]).

input_clause(d_times_d_is_c,hypothesis,
    [++product(g2,d,d,c)]).

%----Definition of the isomorphism 
input_clause(a_maps_to_c,hypothesis,
    [++equalish(an_isomorphism(a),c)]).

input_clause(b_maps_to_d,hypothesis,
    [++equalish(an_isomorphism(b),d)]).

%----Denial that the isomorphism is indeed one 
input_clause(d1_member_of_group1,hypothesis,
    [++group_member(d1,g1)]).

input_clause(d2_member_of_group1,hypothesis,
    [++group_member(d2,g1)]).

input_clause(d3_member_of_group1,hypothesis,
    [++group_member(d3,g1)]).

input_clause(d1_times_d2_is_d3,hypothesis,
    [++product(g1,d1,d2,d3)]).

input_clause(prove_product_holds_in_group2,conjecture,
    [--product(g2,an_isomorphism(d1),an_isomorphism(d2),
an_isomorphism(d3))]).
%--------------------------------------------------------------------------
