%--------------------------------------------------------------------------
% File     : MGT014+1 : TPTP v2.2.1. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : If orgainzation size increases, its complexity cannot decrease
% Version  : [PB+94] axioms.
% English  : If the size of an organization gets bigger, its complexity
%            cannot get smaller (in lack of reorganization).

% Refs     : [PB+94] Peli et al. (1994), A Logical Approach to Formalizing 
%          : [Kam94] Kamps (1994), Email to G. Sutcliffe
%          : [Kam95] Kamps (1995), Email to G. Sutcliffe
% Source   : [Kam94]
% Names    :

% Status   : theorem
% Rating   : 0.00 v2.1.0
% Syntax   : Number of formulae    :   17 (   1 unit)
%            Number of atoms       :   48 (  20 equality)
%            Maximal formula depth :    4 (   3 average)
%            Number of connectives :   31 (   0 ~  ;   0  |;  15  &)
%                                         (   0 <=>;  16 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    7 (   0 propositional; 1-3 arity)
%            Number of functors    :    0 (   0 constant; --- arity)
%            Number of variables   :   56 (   0 singleton;  56 !;   0 ?)
%            Maximal term depth    :    1 (   1 average)

% Comments : "Not published due to publication constraints." [Kam95].
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%--------------------------------------------------------------------------
%----Subsitution axioms
input_formula(complexity_substitution_1,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & complexity(A,C,D) )
     => complexity(B,C,D) )   )).

input_formula(complexity_substitution_2,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & complexity(C,A,D) )
     => complexity(C,B,D) )   )).

input_formula(complexity_substitution_3,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & complexity(C,D,A) )
     => complexity(C,D,B) )   )).

input_formula(greater_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(A,C) )
     => greater(B,C) )   )).

input_formula(greater_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(C,A) )
     => greater(C,B) )   )).

input_formula(organization_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & organization(A,C) )
     => organization(B,C) )   )).

input_formula(organization_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & organization(C,A) )
     => organization(C,B) )   )).

input_formula(reorganization_free_substitution_1,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & reorganization_free(A,C,D) )
     => reorganization_free(B,C,D) )   )).

input_formula(reorganization_free_substitution_2,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & reorganization_free(C,A,D) )
     => reorganization_free(C,B,D) )   )).

input_formula(reorganization_free_substitution_3,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & reorganization_free(C,D,A) )
     => reorganization_free(C,D,B) )   )).

input_formula(size_substitution_1,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & size(A,C,D) )
     => size(B,C,D) )   )).

input_formula(size_substitution_2,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & size(C,A,D) )
     => size(C,B,D) )   )).

input_formula(size_substitution_3,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & size(C,D,A) )
     => size(C,D,B) )   )).

input_formula(time_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & time(A) )
     => time(B) )   )).

%----Problem axioms
input_formula(mp6_1,axiom,(
    ! [X,Y] : 
      ~ ( greater(X,Y)
        & equal(X,Y) )   )).

input_formula(mp6_2,axiom,(
    ! [X,Y] : 
      ~ ( greater(X,Y)
        & greater(Y,X) )   )).

%----Labelling the time variable.
input_formula(mp15,axiom,(
    ! [X,T] : 
      ( organization(X,T)
     => time(T) )   )).

%----On time.
input_formula(mp16,axiom,(
    ! [T1,T2] : 
      ( ( time(T1)
        & time(T2) )
     => ( greater(T1,T2)
        | equal(T1,T2)
        | greater(T2,T1) ) )   )).

%----On the notation of of reorganization-free periods.
input_formula(mp17,axiom,(
    ! [X,T1,T2] : 
      ( reorganization_free(X,T1,T2)
     => reorganization_free(X,T2,T1) )   )).

%----Every organization can have only one size at a time.
input_formula(mp19,axiom,(
    ! [X,S1,S2,T1,T2] : 
      ( ( organization(X,T1)
        & organization(X,T2)
        & size(X,S1,T1)
        & size(X,S2,T2)
        & equal(T1,T2) )
     => equal(S1,S2) )   )).

input_formula(t11_FOL,hypothesis,(
    ! [X,S1,S2,T1,T2] : 
      ( ( organization(X,T1)
        & organization(X,T2)
        & reorganization_free(X,T1,T2)
        & size(X,S1,T1)
        & size(X,S2,T2)
        & greater(T2,T1) )
     => ~ greater(S1,S2) )   )).

input_formula(t12_FOL,hypothesis,(
    ! [X,C1,C2,T1,T2] : 
      ( ( organization(X,T1)
        & organization(X,T2)
        & reorganization_free(X,T1,T2)
        & complexity(X,C1,T1)
        & complexity(X,C2,T2)
        & greater(T2,T1) )
     => ~ greater(C1,C2) )   )).

input_formula(t14_FOL,conjecture,(
    ! [X,C1,C2,S1,S2,T1,T2] : 
      ( ( organization(X,T1)
        & organization(X,T2)
        & reorganization_free(X,T1,T2)
        & complexity(X,C1,T1)
        & complexity(X,C2,T2)
        & size(X,S1,T1)
        & size(X,S2,T2)
        & greater(S2,S1) )
     => ~ greater(C1,C2) )   )).
%--------------------------------------------------------------------------
