%--------------------------------------------------------------------------
% File     : MGT024+1 : TPTP v2.2.1. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : Subpopulation growth rates are in equilibria
% Version  : [PB+94] axioms : Reduced & Augmented > Complete.
% English  : If a subpopulation has positive growth rate, then the other 
%            subpopulation must have negative growth rate in equilibrium. 

% Refs     : [PM93]  Peli & Masuch (1993), The Logic of Propogation Strateg
%          : [PM94]  Peli & Masuch (1994), The Logic of Propogation Strateg
%          : [Kam95] Kamps (1995), Email to G. Sutcliffe
% Source   : [Kam95]
% Names    : 

% Status   : theorem
% Rating   : 0.00 v2.1.0
% Syntax   : Number of formulae    :   30 (   1 unit)
%            Number of atoms       :   99 (  37 equality)
%            Maximal formula depth :    6 (   3 average)
%            Number of connectives :   72 (   3 ~  ;   4  |;  32  &)
%                                         (   0 <=>;  33 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    8 (   0 propositional; 1-4 arity)
%            Number of functors    :    7 (   3 constant; 0-2 arity)
%            Number of variables   :   84 (   0 singleton;  84 !;   0 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%--------------------------------------------------------------------------
%----Subsitution axioms
input_formula(equilibrium_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(equilibrium(A),equilibrium(B)) )   )).

input_formula(growth_rate_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(growth_rate(A,C),growth_rate(B,C)) )   )).

input_formula(growth_rate_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(growth_rate(C,A),growth_rate(C,B)) )   )).

input_formula(number_of_organizations_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(number_of_organizations(A,C),
number_of_organizations(B,C)) )   )).

input_formula(number_of_organizations_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(number_of_organizations(C,A),
number_of_organizations(C,B)) )   )).

input_formula(resources_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(resources(A,C),resources(B,C)) )   )).

input_formula(resources_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(resources(C,A),resources(C,B)) )   )).

input_formula(constant_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & constant(A) )
     => constant(B) )   )).

input_formula(decreases_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & decreases(A) )
     => decreases(B) )   )).

input_formula(environment_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & environment(A) )
     => environment(B) )   )).

input_formula(greater_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(A,C) )
     => greater(B,C) )   )).

input_formula(greater_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(C,A) )
     => greater(C,B) )   )).

input_formula(greater_or_equal_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(A,C) )
     => greater_or_equal(B,C) )   )).

input_formula(greater_or_equal_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(C,A) )
     => greater_or_equal(C,B) )   )).

input_formula(in_environment_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(A,C) )
     => in_environment(B,C) )   )).

input_formula(in_environment_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(C,A) )
     => in_environment(C,B) )   )).

input_formula(subpopulations_substitution_1,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(A,C,D,E) )
     => subpopulations(B,C,D,E) )   )).

input_formula(subpopulations_substitution_2,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,A,D,E) )
     => subpopulations(C,B,D,E) )   )).

input_formula(subpopulations_substitution_3,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,A,E) )
     => subpopulations(C,D,B,E) )   )).

input_formula(subpopulations_substitution_4,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,E,A) )
     => subpopulations(C,D,E,B) )   )).

%----Problem axioms
%----MP. The time points when FM and EP are present in the environment
%----occur during the environment sustains.
input_formula(mp_time_point_occur,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T) )
     => in_environment(E,T) )   )).

%----MP. If both subpopulations are present in the environment, then the
%----number of organizations is positive in this environment.
input_formula(mp_positive_number_of_organizations,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T) )
     => greater(number_of_organizations(E,T),zero) )   )).

%----MP. on equilibrium
input_formula(mp_equilibrium,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & greater_or_equal(T,equilibrium(E)) )
     => ~ greater(equilibrium(E),T) )   )).

%----A3. Resource availability decreases until equilibrium is reached.
input_formula(a3,hypothesis,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T)
        & greater(number_of_organizations(E,T),zero) )
     => ( ( greater(equilibrium(E),T)
         => decreases(resources(E,T)) )
        & ( ~ greater(equilibrium(E),T)
         => constant(resources(E,T)) ) ) )   )).

%----A6. If resource availability decreases, then the number of
%----organizations increases or constant.
input_formula(a6,hypothesis,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T) )
     => ( ( decreases(resources(E,T))
         => ~ decreases(number_of_organizations(E,T)) )
        & ( constant(resources(E,T))
         => constant(number_of_organizations(E,T)) ) ) )   )).

%----L7. If one of the two subpopulations has positive growth rate, then
%----the other subpopulation must have negative growth rate if the total
%----number of organizations is constant.
input_formula(l7,hypothesis,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T)
        & constant(number_of_organizations(E,T)) )
     => ( ( equal(growth_rate(first_movers,T),zero)
          & equal(growth_rate(efficient_producers,T),zero) )
        | ( greater(growth_rate(first_movers,T),zero)
          & greater(zero,growth_rate(efficient_producers,T)) )
        | ( greater(growth_rate(efficient_producers,T),zero)
          & greater(zero,growth_rate(first_movers,T)) ) ) )   )).

%----GOAL: L6. If a subpopulation has positive growth rate, then the
%----other subpopulation must have negative growth rate in equilibrium.
input_formula(prove_l6,conjecture,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T)
        & greater_or_equal(T,equilibrium(E)) )
     => ( ( equal(growth_rate(first_movers,T),zero)
          & equal(growth_rate(efficient_producers,T),zero) )
        | ( greater(growth_rate(first_movers,T),zero)
          & greater(zero,growth_rate(efficient_producers,T)) )
        | ( greater(growth_rate(efficient_producers,T),zero)
          & greater(zero,growth_rate(first_movers,T)) ) ) )   )).
%--------------------------------------------------------------------------
