%--------------------------------------------------------------------------
% File     : RNG008-5 : TPTP v2.2.1. Released v1.0.0.
% Domain   : Ring Theory
% Problem  : Boolean rings are commutative
% Version  : [MOW76] axioms : Augmented.
%            Theorem formulation : Equality.
% English  : Given a ring in which for all x, x * x = x, prove that for 
%            all x and y, x * y = y * x.

% Refs     : [MOW76] McCharen et al. (1976), Problems and Experiments for a
%          : [PS81]  Peterson & Stickel (1981), Complete Sets of Reductions
% Source   : [ANL]
% Names    : commute.ver1.in [ANL]

% Status   : unsatisfiable
% Rating   : 0.67 v2.2.0, 0.71 v2.1.0, 0.50 v2.0.0
% Syntax   : Number of clauses    :   40 (   0 non-Horn;  16 unit;  23 RR)
%            Number of literals   :   93 (  24 equality)
%            Maximal clause size  :    5 (   2 average)
%            Number of predicates :    3 (   0 propositional; 2-3 arity)
%            Number of functors   :    7 (   4 constant; 0-2 arity)
%            Number of variables  :  123 (   2 singleton)
%            Maximal term depth   :    3 (   1 average)

% Comments : Extra lemmas based on [PS81] equality axioms.
%--------------------------------------------------------------------------
%----Include Reflexivity, symmetry and transitivity, of equality 
include('Axioms/EQU001-0.ax').
%----Include ring theory axioms 
include('Axioms/RNG001-0.ax').
%----Include ring theory equality axioms 
include('Axioms/RNG001-0.eq').
%--------------------------------------------------------------------------
%----The next six clauses are the extra lemmas.
%----Inverse of identity is identity 
input_clause(additive_inverse_identity,axiom,
    [++sum(additive_inverse(additive_identity),additive_identity,
additive_identity)]).

%----Inverse of inverse of X is X 
input_clause(additive_inverse_additive_inverse,axiom,
    [++sum(additive_inverse(additive_inverse(X)),additive_identity,X)]).

%----Behavior of additive_identity and the multiplication operation 
input_clause(multiply_additive_id1,axiom,
    [++product(X,additive_identity,additive_identity)]).

input_clause(multiply_additive_id2,axiom,
    [++product(additive_identity,X,additive_identity)]).

%----Inverse of (x + y) is additive_inverse(x) + additive_inverse(y), 
input_clause(distribute_additive_inverse,axiom,
    [++sum(additive_inverse(X),additive_inverse(Y),
additive_inverse(add(X,Y)))]).

%----x * additive_inverse(y) = additive_inverse (x * y), 
input_clause(multiply_additive_inverse,axiom,
    [++product(X,additive_inverse(Y),additive_inverse(multiply(X,Y)))]).

%----Clauses for the theorem 
input_clause(x_squared_is_x,hypothesis,
    [++product(X,X,X)]).

input_clause(a_times_b_is_c,hypothesis,
    [++product(a,b,c)]).

input_clause(prove_b_times_a_is_c,conjecture,
    [--product(b,a,c)]).
%--------------------------------------------------------------------------
